@@ -1,7 +1,8 @@
 from pydantic import BaseModel
 from pydantic.color import Color
 
-from moontour_common.models.rooms.health_room import HealthRoom, START_HEALTH
+from moontour_common.models import Guess
+from moontour_common.models.rooms.health_room import HealthRoom, START_HEALTH, HealthPhase
 from moontour_common.models.rooms.room import RoomMode
 from moontour_common.models.user import User
 
@@ -12,6 +13,10 @@ class Team(BaseModel):
     players: list[User] = []
 
 
+class TeamsPhase(HealthPhase):
+    guesses: dict[str, Guess] = {}  # User ID to guess
+
+
 class TeamsRoom(HealthRoom):
     @staticmethod
     def get_mode() -> RoomMode:
@@ -22,3 +27,4 @@ class TeamsRoom(HealthRoom):
         'red': Team(color=Color('red')),
         'blue': Team(color=Color('blue')),
     }
+    phases: list[TeamsPhase] = []
